@@ -1,7 +1,7 @@
 from . import Command
 
 
-class BaseCommand(Command):
+class update(object):
     
     help = "this is a description of the update command"
     
@@ -10,5 +10,8 @@ class BaseCommand(Command):
         parser.add_argument('blah', help='name of the blah to update')
         parser.add_argument('-b','--bar', help='the bar parameter')
         
+    def __unicode__(self):
+        return 'update'
+        
     def run(self, argv):
         print "running %s" % argv
\ No newline at end of file
