@@ -5,13 +5,19 @@ from . import Route
 
 
 
-class BaseRoute(Route):
+class URLRoute(Route):
     
     patterns = []
     
     def __init__(self):
         pass
     
+    def __unicode__(self):
+        return None
+    
+    def _uid(self):
+        return None
+    
     def is_valid(self, identifier):
         matches = [True for p in self.patterns if p.match(identifier)] 
         return len(matches) != 0
@@ -19,5 +25,4 @@ class BaseRoute(Route):
     
     def fetch(self, identifier):
         matches = [p.match(identifier).groupdict() for p in self.patterns if p.match(identifier)] 
-        print matches
-        print 'route to fetch from tarball'
\ No newline at end of file
+        raise RouteException('fetch from tarball not yet implemented')
\ No newline at end of file
